#
# spec file for package libmsiecf
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libmsiecf
%define lname	libmsiecf1
Version:        20240425
Release:        1.4
Summary:        Library to parse MS Internet Explorer Cache Files
License:        GFDL-1.3-or-later AND LGPL-3.0-or-later
Group:          Productivity/File utilities
URL:            https://github.com/libyal/libmsiecf
Source:         https://github.com/libyal/libmsiecf/releases/download/%version/%name-alpha-%version.tar.gz
Source2:        https://github.com/libyal/libmsiecf/releases/download/%version/%name-alpha-%version.tar.gz.asc
Source3:        %name.keyring
Source8:        MSIE_Cache_File_index.dat_format.pdf
BuildRequires:  %python_module devel
BuildRequires:  %python_module setuptools
BuildRequires:  c_compiler
BuildRequires:  pkg-config
BuildRequires:  python-rpm-macros
BuildRequires:  pkgconfig(libbfio) >= 20240414
BuildRequires:  pkgconfig(libcdata) >= 20240414
BuildRequires:  pkgconfig(libcerror) >= 20240413
BuildRequires:  pkgconfig(libcfile) >= 20240414
BuildRequires:  pkgconfig(libclocale) >= 20240414
BuildRequires:  pkgconfig(libcnotify) >= 20240414
BuildRequires:  pkgconfig(libcpath) >= 20240414
BuildRequires:  pkgconfig(libcsplit) >= 20240414
BuildRequires:  pkgconfig(libcthreads) >= 20240413
BuildRequires:  pkgconfig(libfdatetime) >= 20240415
BuildRequires:  pkgconfig(libfguid) >= 20240415
BuildRequires:  pkgconfig(libfole) >= 20240416
BuildRequires:  pkgconfig(libfvalue) >= 20240415
BuildRequires:  pkgconfig(libuna) >= 20240414
%python_subpackages
# Various notes: https://en.opensuse.org/libyal

%description
libmsiecf is a library to parse MS Internet Explorer Cache Files.

%package -n %lname
Summary:        Library to parse MS Internet Explorer Cache Files
License:        LGPL-3.0-or-later
Group:          System/Libraries

%description -n %lname
libmsiecf is a library to parse MS Internet Explorer Cache Files.

%package tools
Summary:        Utilities to inspect MS Internet Explorer Cache Files
License:        LGPL-3.0-or-later
Group:          System/Filesystems

%description tools
Several tools for reading MS Internet Explorer Cache files.

%package devel
Summary:        Development files for %name
License:        GFDL-1.3-or-later AND LGPL-3.0-or-later
Group:          Development/Libraries/C and C++
Requires:       %lname = %version
Requires:       libbfio-devel

%description devel
libmsiecf is a library to parse MS Internet Explorer Cache Files.

This subpackage contains libraries and header files for developing
applications that want to make use of %name.

%prep
%autosetup -p1
cp %_sourcedir/*.pdf .

%build
%{python_expand #
echo "V_%version { global: *; };" >v.sym
%configure --disable-static --enable-wide-character-type --enable-python \
	PYTHON_VERSION="%{$python_bin_suffix}" \
	LDFLAGS="-Wl,--version-script=$PWD/v.sym"
grep ' '' ''local' config.log && exit 1
%make_build
%make_install DESTDIR="%_builddir/rt"
%make_build clean
}

%install
mv %_builddir/rt/* %buildroot/
find %buildroot -type f -name "*.la" -delete -print

%ldconfig_scriptlets -n %lname

%files -n %lname
%license COPYING*
%_libdir/libmsiecf.so.*

%files -n %name-tools
%_bindir/msiecf*
%_mandir/man1/msiecf*.1*

%files -n %name-devel
%doc MSIE_Cache_File*.pdf
%_includedir/libmsiecf.h
%_includedir/libmsiecf/
%_libdir/libmsiecf.so
%_libdir/pkgconfig/libmsiecf.pc
%_mandir/man3/libmsiecf.3*

%files %python_files
%license COPYING*
%python_sitearch/pymsiecf.so

%changelog
* Thu Apr 25 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 20240425
  * No changelog was provided
* Fri Feb  9 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 20240209
  * No user-visible changes
* Mon Feb  5 2024 Jan Engelhardt <jengelh@inai.de>
- Use python-setuptools for python distutils backport
  gh#libyal/libbde#68
* Sun Dec  3 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 20231203
  * Improved Python Unicode handling
* Tue Aug  1 2023 Greg Freemyer <Greg.Freemyer@gmail.com>
- use %%{?sle15_python_module_pythons} for opensuse15.5 compatibility
* Tue Jan  3 2023 Jan Engelhardt <jengelh@inai.de>
- Add missing Require on libbfio-devel.
* Sat Nov 26 2022 Jan Engelhardt <jengelh@inai.de>
- Delete system-libs.patch (not needed - system libs are
  autodetected)
* Mon Oct 24 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 20221024
  * No changelog was provided
* Mon Aug  8 2022 Jan Engelhardt <jengelh@inai.de>
- Add forced symvers
* Mon Jan 24 2022 Jan Engelhardt <jengelh@inai.de>
- Enable multipython builds.
* Fri May 14 2021 Jan Engelhardt <jengelh@inai.de>
- Update to snapshot 20210506 (9e94c3b8)
  * No changelog was provided
- Add system-libs.patch
* Wed Dec 30 2020 Greg Freemyer <Greg.Freemyer@gmail.com>
- updated to 0~20200710
  * Code clean up
- remove BuildRequires: pkg-config
- add COPYING* to %%license line
* Thu Apr 30 2020 Greg Freemyer <Greg.Freemyer@gmail.com>
- remove python2 submodule
* Wed Apr  8 2020 Greg Freemyer <Greg.Freemyer@gmail.com>
- updated to 0~20191221
  * changes for libcdata
- rename python-msiecf to python2-msiecf
- add python3-msiecf submodule
* Wed Mar 27 2019 Greg Freemyer <Greg.Freemyer@gmail.com>
- updated to 0~20181227
  * changes to the API
  * updates to support libcdata API change
  * worked on python bindings
  * code cleanup
* Fri May  8 2015 Greg.Freemyer@gmail.com
- updated to 0~20150314
  * worked on Python bindings cache directory support
* Wed Jan 14 2015 Greg.Freemyer@gmail.com
- update to 0~20150106
  * 2015 update
  * worked on Python 3 support
  * worked on tests
  * code clean up
  * bug fix in Python-bindings
  * update Python-bindings tests
- update URL to the new github site
- replace Source: field with fully defined URL
- remove DL-URL comment
- add BuildRequires for libyal packages newly released
* Tue Aug 26 2014 Greg.Freemyer@gmail.com
- add these 2 lines to python sub-project to ensure proper syncronization between versions
  * Provides:	pyevt = %%version
* Wed Aug 13 2014 Greg.Freemyer@gmail.com
- update to 0~20140731
  * bug fix in Python-bindings
  * worked on Python bindings
  * worked on setup.py
  * 2014 update
  * updated dependencies
* Tue Nov 26 2013 Greg.Freemyer@gmail.com
- update to 0~20131015
  * updated dependencies
  * improved pymsiecf as integer functions
  * worked on setup.py, largely for MSI builds
* Tue Aug 27 2013 Greg.Freemyer@gmail.com
- update to 0~20130806
  * fixes for building with stand-alone libuna and libbfio
  * bug fix in pymsiecf file object libbfio glue code
  * worked on tests
- use libyal packages from factory where possible
* Wed Jul 31 2013 Greg.Freemyer@gmail.com
- updated to v0~20130529
  * updated dependencies
  * worked on pymsiecf simple inheritance of leak, redirected and url items
  * worked on hash calculation
  * worked on tests
  * bug fix in record scan due to recent dependency update
  * textual changes
  * updates and bug fixes in pymsiecf
  * fixed codepage 1255 restriction
  * fixed codepage 949 and 950 restriction
- change to gz compression to simplyfy download/convert
- use libyal packages from factory where possible
* Thu Apr 18 2013 jengelh@inai.de
- fixed: python-libmsiecf required unprovidable libmsiecf%%soname
* Fri Apr  5 2013 jengelh@inai.de
- Cleanups: Set RPM group, license, summary and description
  metadata; remove unused %%py_requires; do not bloat shlib package
  with documentation
- Use system libraries instead of bundled ones where possible
- Name the tools package according to upstream's recommendation
- Drop unnecessary -fno-strict-aliasing
* Wed Mar 27 2013 Greg.Freemyer@gmail.com
- initial package (version 0~20130317) for build.opensuse.org
